import * as types from "./types";
/**
 * Before we send styles to freeStyle we should convert any CSSType<T> to string
 * Call this whenever something might be a CSSType.
 */
export declare function ensureString(x: any): string;
/**
 * Ensures string for all values of an object
 */
export declare function ensureStringObj(object: any): types.CSSProperties;
/** Sets the target tag where we write the css on style updates */
export declare const setTargetTag: (tag: {
    innerHTML: string;
}) => void;
/**
 * Insert `raw` CSS as a string. This is useful for e.g.
 * - third party CSS that you are customizing with template strings
 * - generating raw CSS in JavaScript
 * - reset libraries like normalize.css that you can use without loaders
 */
export declare function cssRaw(mustBeValidCSS: string): void;
/**
 * Renders styles to the singleton tag imediately
 * NOTE: You should only call it on initial render to prevent any non CSS flash.
 * After that it is kept sync using `requestAnimationFrame` and we haven't noticed any bad flashes.
 **/
export declare function forceRenderStyles(): void;
/**
 * Helps with testing. Reinitializes FreeStyle + raw
 */
export declare function reinit(): void;
/**
 * Allows use to use the stylesheet in a node.js environment
 */
export declare const css: () => string;
/**
 * Takes CSSProperties and return a generated className you can use on your component
 */
export declare function style(...objects: types.NestedCSSProperties[]): string;
export declare function fontFace(...fontFace: types.FontFace[]): void;
/**
 * Takes CSSProperties and registers it to a global selector (body, html, etc.)
 */
export declare function cssRule(selector: string, ...objects: types.NestedCSSProperties[]): void;
/**
 * Takes Keyframes and returns a generated animation name
 */
export declare function keyframes(frames: types.KeyFrames): string;
/**
 * Helper for you to create a CSSFunction
 * Assumption is that most css function fall into this pattern:
 * `function-name(param [, param])`
 */
export declare function cssFunction(functionName: string, ...params: types.CSSValueGeneral[]): string;
/**
 * Merges various styles into a single style object.
 * Note: if two objects have the same property the last one wins
 */
export declare function extend(...objects: types.NestedCSSProperties[]): types.NestedCSSProperties;
/**
 * Utility to join classes conditionally
 */
export declare function classes(...classes: (string | boolean | undefined | null)[]): string;
/**
 * Helps customize styles with media queries
 */
export declare const media: (mediaQuery: {
    type?: "screen" | "print" | "all" | undefined;
    orientation?: "landscape" | "portrait" | undefined;
    minWidth?: number | undefined;
    maxWidth?: number | undefined;
}, ...objects: types.CSSProperties[]) => types.CSSProperties;
