"use strict";
var index_1 = require('../index');
var assert = require('assert');
describe("initial test", function () {
    it("should pass", function () {
        index_1.reinit();
        assert(index_1.css() === '');
        index_1.style({ color: 'red' });
        assert.equal(index_1.css(), '.f1jvcvsh{color:red}');
    });
    it("reinit should clear", function () {
        index_1.reinit();
        assert(index_1.css() === '');
        index_1.style({ color: 'red' });
        assert.equal(index_1.css(), '.f1jvcvsh{color:red}');
    });
    it("child same", function () {
        index_1.reinit();
        index_1.style({ color: 'red', nested: { '&>*': { color: 'red' } } });
        assert.equal(index_1.css(), '.f1nv0def,.f1nv0def>*{color:red}');
    });
    it("child different", function () {
        index_1.reinit();
        index_1.style({ color: 'red', nested: { '&>*': { color: 'blue' } } });
        assert.equal(index_1.css(), '.fv84gyi{color:red}.fv84gyi>*{color:blue}');
    });
    it("media same", function () {
        index_1.reinit();
        index_1.style({
            color: 'red',
            nested: {
                '@media (min-width: 400px)': { color: 'red' }
            }
        });
        assert.equal(index_1.css(), '.f12z113b{color:red}@media (min-width: 400px){.f12z113b{color:red}}');
    });
    it("media different", function () {
        index_1.reinit();
        index_1.style({ color: 'red', nested: { '@media (min-width: 400px)': { color: 'blue' } } });
        assert.equal(index_1.css(), '.fxfrsga{color:red}@media (min-width: 400px){.fxfrsga{color:blue}}');
    });
    it("classes should compose", function () {
        assert.equal(index_1.classes("a", "b"), "a b");
        assert.equal(index_1.classes("a", false && "b"), "a");
        assert.equal(index_1.classes("a", false && "b", "c"), "a c");
    });
    it("transparent string should render transparent in color property", function () {
        index_1.reinit();
        index_1.cssRule('.transparent', { color: 'transparent' });
        index_1.style({ color: 'transparent' });
        assert.equal(index_1.css(), '.transparent{color:transparent}.fwarpl0{color:transparent}');
    });
});
