"use strict";
var index_1 = require('../index');
var assert = require('assert');
describe("extend", function () {
    it("plain objects should be preserved", function () {
        assert.deepEqual(index_1.extend({ color: 'red' }), { color: 'red' });
    });
    it("nested objects should get flattened", function () {
        assert.deepEqual(index_1.extend({
            nested: { '&:hover': { color: 'red' } }
        }), {
            '&:hover': {
                color: 'red'
            }
        });
    });
    it("nested objects should get flattened and merge", function () {
        assert.deepEqual(index_1.extend({ color: 'grey' }, { nested: { '&:hover': { color: 'red' } } }), {
            color: 'grey',
            '&:hover': {
                color: 'red'
            }
        });
    });
    it("nested objects should merge", function () {
        assert.deepEqual(index_1.extend({ color: 'grey' }, { backgroundColor: 'grey' }, { nested: { '&:hover': { color: 'red' } } }, { nested: { '&:hover': { backgroundColor: 'red' } } }), {
            color: 'grey',
            backgroundColor: 'grey',
            '&:hover': {
                color: 'red',
                backgroundColor: 'red'
            }
        });
    });
    it("extend should compose i.e. should be nestable", function () {
        assert.deepEqual(index_1.extend(index_1.extend({ nested: { '&:hover': { color: 'red' } } }), { nested: { '&:hover': { backgroundColor: 'red' } } }), {
            '&:hover': {
                color: 'red',
                backgroundColor: 'red'
            }
        });
    });
    it("extend should compose i.e. should be truly nestable", function () {
        assert.deepEqual(index_1.extend(index_1.extend({ nested: { '&:hover': { color: 'red' } } }), index_1.extend({ nested: { '&:hover': { backgroundColor: 'red' } } })), {
            '&:hover': {
                color: 'red',
                backgroundColor: 'red'
            }
        });
    });
    it("different nested keys should not merge", function () {
        assert.deepEqual(index_1.extend({ nested: { '&:hover': { color: 'red' } } }, { nested: { '&:hover': { backgroundColor: 'red' } } }, { nested: { '&:focus': { backgroundColor: 'red' } } }, { nested: { '&:hover': { fontSize: '14px' }, '&:focus': { fontFamily: 'arial' } } }), {
            '&:hover': {
                fontSize: '14px',
                color: 'red',
                backgroundColor: 'red'
            },
            '&:focus': {
                fontFamily: 'arial',
                backgroundColor: 'red'
            }
        });
    });
});
